#include "ls.h"
#include "true.h"
#include "false.h"
#include "rm.h"
#include "whoami.h"
#include "mount.h"
#include "rmdir.h"
#include "umount.h"
#include "cat.h"
#include "mkfifo.h"
#include "cp.h"
#include "hostname.h"
#include "sh.h"

int (*(commands_exec[256]))()={
			ls_main,
			true_main,
			false_main,
			rm_main,
			whoami_main,
			mount_main,
			rmdir_main,
			umount_main,
			cat_main,
			mkfifo_main,
			cp_main,
			hostname_main,
			sh_main,
			NULL
};

char *commands_name[256]={
			"ls",
			"true",
			"false",
			"rm",
			"whoami",
			"mount",
			"rmdir",
			"umount",
			"cat",
			"mkfifo",
			"cp",
			"hostname",
			"sh",
			NULL
};
